/* 
 * Copyright (C) 2003 the xine project
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * $Id: menu.h,v 1.3 2004/11/03 19:47:35 dsalt Exp $
 *
 * main/context menu creation / handling
 */

#ifndef HAVE_MENU_H
#define HAVE_MENU_H

#include <gtk/gtk.h>

#define num_menu_items(tree) (sizeof ((tree)) / sizeof ((tree)[0]))

GtkWidget *create_menu_tree (GtkItemFactory **, GtkWidget *window,
			     GtkAccelGroup **, GtkItemFactoryEntry *,
			     gint items);
void create_menus (GtkWidget *window);

#endif
